pub struct WidgetRegion {
pub param_id: u32,
pub widget_type: WidgetType,
pub x: f32,
pub y: f32,
pub w: f32,
pub h: f32,
pub cx: f32,
pub cy: f32,
pub radius: f32,
pub normalized_value: f32,
pub dropdown_anchor_y: f32,
}Expand description
A widget’s hit region on screen.
Fields
param_id: u32widget_type: WidgetTypex: f32y: f32w: f32h: f32cx: f32Center x/y and radius for knob (circular hit test).
cy: f32radius: f32normalized_value: f32dropdown_anchor_y: f32Bottom Y of the dropdown button box, set at draw time. Used to position the popup directly below the visual button.