pub struct Section {
pub label: Option<&'static str>,
pub widgets: Vec<GridWidget>,
}Expand description
A group of widgets with an optional section label.
Used as input to GridLayout::build(). Bare GridWidgets convert into
ungrouped sections via From, so orphan widgets only need .into().
Fields
label: Option<&'static str>widgets: Vec<GridWidget>Trait Implementations
Sourceimpl From<GridWidget> for Section
impl From<GridWidget> for Section
Sourcefn from(w: GridWidget) -> Section
fn from(w: GridWidget) -> Section
Converts to this type from the input type.