ImageId

Struct ImageId 

pub struct ImageId(pub u32);
Opaque handle to a backend-registered image.

Returned by RenderBackend::register_image; passed to RenderBackend::draw_image. Valid until unregister_image or the backend is dropped. Two backends do not share ids - ids from one backend must not be used with another.

Tuple Fields

0: u32

Implementations

Source

impl ImageId

pub const INVALID: ImageId

Sentinel value returned by the default trait impls when a backend does not override register_image.