BuiltinEditor

Struct BuiltinEditor 

pub struct BuiltinEditor<P: Params> { /* private fields */ }
Built-in editor that renders parameter widgets to a pixel buffer.

Uses the CPU backend (tiny-skia) for software rasterization. When open() is called, creates a platform view and blits pixels at ~60fps.

Implementations

Source

impl<P: Params + 'static> BuiltinEditor<P>

pub fn new(params: Arc<P>, layout: PluginLayout) -> Self

pub fn new_with_layout(params: Arc<P>, layout: Layout) -> Self

pub fn new_grid(params: Arc<P>, layout: GridLayout) -> Self

pub fn with_theme(self, theme: Theme) -> Self

pub fn render(&mut self)

Render the full UI to the internal CPU pixel buffer.

pub fn pixel_data(&self) -> Option<&[u8]>

Get the raw pixel data after rendering (RGBA premultiplied).

pub fn set_context(&mut self, context: EditorContext)

Set the editor context (host callbacks) without opening the CPU view.

pub fn render_to(&mut self, backend: &mut dyn RenderBackend)

Render all widgets to an external RenderBackend.

Used by truce-gpu to draw through the GPU backend instead of the internal CPU backend.

pub fn on_mouse_down(&mut self, x: f32, y: f32)

pub fn on_mouse_dragged(&mut self, x: f32, y: f32)

pub fn on_mouse_up(&mut self, _x: f32, _y: f32)

pub fn on_double_click(&mut self, x: f32, y: f32)

pub fn on_scroll(&mut self, x: f32, y: f32, delta_y: f32)

pub fn on_mouse_moved(&mut self, x: f32, y: f32) -> bool